@@ -1,5 +1,5 @@
 /*!
- * MorphSVGPlugin 3.3.4
+ * MorphSVGPlugin 3.5.1
  * https://greensock.com
  *
  * @license Copyright 2008-2020, GreenSock. All rights reserved.
@@ -13,6 +13,7 @@ import { getRawPath, reverseSegment, stringToRawPath, rawPathToString, convertTo
 
 let gsap, _toArray, _lastLinkedAnchor, _doc, _coreInitted, PluginClass,
 	_getGSAP = () => gsap || (typeof(window) !== "undefined" && (gsap = window.gsap) && gsap.registerPlugin && gsap),
+	_isFunction = value => typeof(value) === "function",
 	_atan2 = Math.atan2,
 	_cos = Math.cos,
 	_sin = Math.sin,
@@ -555,8 +556,9 @@ let gsap, _toArray, _lastLinkedAnchor, _doc, _coreInitted, PluginClass,
 
 
 export const MorphSVGPlugin = {
-	version:"3.3.4",
-	name:"morphSVG",
+	version: "3.5.1",
+	name: "morphSVG",
+	rawVars: 1, // otherwise "render" would be interpreted as a function-based value.
 	register(core, Plugin) {
 		gsap = core;
 		PluginClass = Plugin;
@@ -568,12 +570,21 @@ export const MorphSVGPlugin = {
 			_log("invalid shape");
 			return false;
 		}
-		(typeof(value) === "string" || value.getBBox || value[0]) && (value = {shape:value});
+		_isFunction(value) && (value = value.call(tween, index, target, targets));
+		let type, p, pt, shape, isPoly, shapeIndex, map, startSmooth, endSmooth, start, end, i, j, l, startSeg, endSeg, precompiled, sData, eData, originFactors, useRotation, offset;
+		if (typeof(value) === "string" || value.getBBox || value[0]) {
+			value = {shape:value};
+		} else if (typeof(value) === "object") { // if there are any function-based values, parse them here (and make a copy of the object so we're not modifying the original)
+			type = {};
+			for (p in value) {
+				type[p] = _isFunction(value[p]) && p !== "render" ? value[p].call(tween, index, target, targets) : value[p];
+			}
+			value = type;
+		}
 		let cs = target.nodeType ? window.getComputedStyle(target) : {},
 			fill = cs.fill + "",
 			fillSafe = !(fill === "none" || (fill.match(_numExp) || [])[3] === "0" || cs.fillRule === "evenodd"),
-			origins = (value.origin || "50 50").split(","),
-			type, p, pt, shape, isPoly, shapeIndex, map, startSmooth, endSmooth, start, end, i, j, l, startSeg, endSeg, precompiled, sData, eData, originFactors, useRotation, offset;
+			origins = (value.origin || "50 50").split(",");
 		type = (target.nodeName + "").toUpperCase();
 		isPoly = (type === "POLYLINE" || type === "POLYGON");
 		if (type !== "PATH" && !isPoly && !value.prop) {
@@ -581,7 +592,7 @@ export const MorphSVGPlugin = {
 			return false;
 		}
 		p = (type === "PATH") ? "d" : "points";
-		if (!value.prop && typeof(target.setAttribute) !== "function") {
+		if (!value.prop && !_isFunction(target.setAttribute)) {
 			return false;
 		}
 		shape = _parseShape(value.shape || value.d || value.points || "", (p === "d"), target);
